      subroutine bck
     & (ncl, jcl, sths, cths, sthv, cthv, sphi,
     & cphi, calph, xi, yj, zk, sxuj, sxdj)
c
c     Jo~eveer, (mai 88) Andrese progr.-st ilips xi, yj, zk
c     reflectance of the 1-st order scattering in tree crowns
c     modified to the BDGP:
c    Bidirectional gap probability in a tree crown for the spherical
c    orientation of leaves. A. Kuusk, The hot spot effect in plant canopy
c    reflectance. - R. Myneny and J. Ross (Eds.), Photon-Vegetation
c    Interactions. Applications in Optical Remote sensing and Plant
c    Ecology. Springer, Berlin, 1991, 139-159.   A. Kuusk  4.01.1986
c    Modified 11.05.1998
c    Modified 12.2012 - elliptical orientation of foliage
c
c    lellips = .true. - ellipsoid, = .false. -- cone + cylinder
c    calph = cos(alph), alph - the angle between ths and thv
c    shl - the hot spot parameter, the size of a leaf (shoot), m
c    sthet? = sin(thet?), cthet? = cos(thet?)
c    sphi = sin(phi), cphi = cos(phi), phi is the relative azimuth
c    aell - crown radius, helco - crown length, htrj - tree height, m
c
c    Input:
c     & (lelli, jcl, ncl, shl, stdns, htr, dbh, hc1, hc2, rcr,
c     & uuu, gg3s, gg3v, glmp, sths, cths, sthv, cthv, sphi,
c     & cphi, calph, xi, yj, zk,
c    Output:
c    sxuj, sxdj), sxuj - up, sxdj - down
c    zxr - local z-coordinate
c
      include 'par.h'
      include 'stands.h'
c
      save chs1, chs3
c      
      data eps/0.001d0/
c
      rintegr(xxx) = (1.d0 - exp(-xxx))/xxx
c
      lellj  = lelli(jcl)
      htrj   = htr(jcl)
      helco  = hc1(jcl)
      aell   = rcr(jcl)
      shlj   = shl(jcl)
c
c  sthedv = sthv, cthedv = -cthv, sphid = +sphi, 
c  cphid = -cphi, calphd = -calph
c
      if (lellj) then
         cell   = .5d0*helco
         zxr    = htrj - cell
c
         call rlips
     &    (xi, yj, zk, sthv, cthv, sphi, cphi, aell, cell, rlout)
         rllv2  = rlout
         call rlips
     &  (xi, yj, zk, sthv, -cthv, sphi, -cphi, aell, cell, rlout)
         rllv3  = rlout
c
         call rlips
     &    (xi, yj, zk, sths, cths, 0.d0, 1.d0, aell, cell, rlout)
         rlls1 = rlout
c
      else
         zxr   = htrj - helco
         vhcyl  = hc2(jcl)
c
         call rkoon
     &   (xi, yj, zk, sthv, cthv, sphi, cphi, 
     &    aell, helco, vhcyl, rlout)
         rllv2  = rlout
         call rkoon
     &   (xi, yj, zk, sthv, -cthv, sphi, -cphi, 
     &    aell, helco, vhcyl, rlout)
         rllv3  = rlout
c
         call rkoon
     &   (xi, yj, zk, sths, cths, 0.d0, 1.d0, 
     &    aell, helco, vhcyl, rlout)
         rlls1 = rlout
c
      endif
c
c                             ! hot-spot correction inside the crown
      uuuj  = uuu(jcl)
      ulgs  = uuuj*gg3s(jcl)
      ulgv  = uuuj*gg3v(jcl)
      rl12u = (rllv2 - rlls1)**2 + (1.d0 - calph)*2.d0*rlls1*rllv2
      if (rl12u .lt. 0.d0) then
         crr0 = 0.d0
      else
         crr0 = sqrt(rl12u)/shlj
      endif
      if (crr0 .lt. eps) then
         xtmp = 1.d0 - crr0*.5d0
      else
         xtmp = rintegr(crr0)
      endif
      chs1 = sqrt(rllv2*rlls1)*xtmp
      xx  = (chs1 - rlls1 - rllv2)*sqrt(ulgs*ulgv)
      bgpu = exp(xx)
c
      rl12d = (rllv3 - rlls1)**2 + (1.d0 + calph)*2.d0*rlls1*rllv3
      if (rl12d .lt. 0.d0) then
         crr0 = 0.d0
      else
         crr0 = sqrt(rl12d)/shlj
      endif
      if (crr0 .lt. eps) then
         xtmp = 1.d0 - crr0*.5d0
      else
         xtmp = rintegr(crr0)
      endif
      chs3 = sqrt(rllv3*rlls1)*xtmp
      xx  = (chs3 - rlls1 - rllv3)*sqrt(ulgs*ulgv)
      bgpd = exp(xx)
c                bgp? - bidirectional gap probability inside the crown
c
c  Probabilities pooj  (A. Jõeveer)
c  the bididrectional gap probability outside the tree crown,
c  poouj - up, poodj - down
c
      x1  = xi + rllv2*sthv*cphi
      y1  = yj + rllv2*sthv*sphi
      z1  = zk + rllv2*cthv + zxr
      x2  = xi + rlls1*sths
      y2  = yj
      z2  = zk + rlls1*cths + zxr
c
      x3  = xi - rllv3*sthv*cphi
      y3  = yj + rllv3*sthv*sphi
      z3  = zk - rllv3*cthv + zxr
c
      call spooj
     & (ncl, x1, y1, z1, x2, y2, z2, x3, y3, z3,
     & rlls1, rllv2, rllv3, sths, cths, sthv, cthv,
     & sphi, cphi, calph, chs1, chs3, poou, pood)
c
      sxuj  = bgpu*poou
      sxdj  = bgpd*pood
c
      return
      end
*
************************************************************************
*
