      subroutine  enel
     & (ncl, jcl, ths, thv, phi, nzs, 
     & bdgfu, bdgfd, btr1u, btr1d)
c
c   Single scattering in a tree crown,  A. Kuusk     29.08.2002
c   The bidirectional gap probability bgp*pooi is integrated 
c   over crown volume using Hammer-Stroud cubature in an ellipsoid,
c   Hammer, P.C., Stroud, A.H. Numerical evaluation of multiple
c   integrals II. Math. Tables and other Aids Comp. 12 (1958), No 64,
c   272-280,
c   or using Gauss-Legendre quadrature in z-direction and the Mysovskikh
c   (1981) algorithm 16.33 in x-y-plain in cone and cylinder.
c   The knots and weights for quadratures are in volint.h, 
c   the probabilities bgp and pooi are calculated in bck, 
c   the integrals are saved in the arrays bdgf?, and the probabilities to
c   see sunlit stem in the arrays btr1?k.
c
c   Elliptical orientation of foliage 12.2012.
c
c  Input:
c     & (lelli, jcl, jths, ncl, shl, stdns, htr, dbh, hc1, hc2, rcr,
c     & uuu, glmp, ths, thv, phi, nzs
c  Output:
c    bdgfu, bdgfd, btr1u, btr1d
c
      include 'par.h'
      include 'stands.h'
      include 'volint.h'
c
      dimension bdgfu(nclmax), btr1u(nclmax)
      dimension bdgfd(nclmax), btr1d(nclmax)
c
      data xi, x2, x3, yj, y2, y3, rlls1, rllv2, rllv3, 
     &     chs1, chs3, cell /12*0.d0/
      data eps/0.1d-7/
*     data pi2/1.570796326794895d0/
c
      sths = sin(ths)
      cths = cos(ths)
      sthv = sin(thv)
      cthv = cos(thv)
      sphi = sin(phi)
      cphi = cos(phi)
      calph  = sthv*sths*cphi + cthv*cths
c         alph = acos(calph) is the angle betveen view directions 
c         ths and thv
c
      lellj   = lelli(jcl)
      aell    = rcr(jcl)
      a2      = aell**2
      sumu    = 0.d0
      sumd    = 0.d0
      htrj    = htr(jcl)
      ntstz   = 2*nzs
c                                                       ellipsoid
      if (lellj) then
         hcrj   = hc1(jcl)
         cell   = hcrj*.5d0
         do itst = 1, netst
            xi    = xetst(itst)*aell
            yj    = yetst(itst)*aell
            zk    = zetst(itst)*cell
            atsti = aetst(itst)*a2*cell
            call bck
     & (ncl, jcl, sths, cths, sthv, cthv, sphi,
     & cphi, calph, xi, yj, zk, sxuj, sxdj)
            sumu = sumu + sxuj*atsti
            sumd = sumd + sxdj*atsti
         enddo
         bdgfu(jcl) = sumu
         bdgfd(jcl) = sumd
      else
         hc1j   = hc1(jcl)
         vhcil  = hc2(jcl)
         hcrj   = hc1j + vhcil
         do itst = 1, ntstz
c                                                        cylinder
            if (vhcil .gt. 0d0) then
               sxyu   = 0.d0
               sxyd   = 0.d0
               aztsti = acztst(itst)/2.d0*vhcil
               zk     = (zctst(itst) - 1.d0)/2.d0*vhcil
               rcirc  = aell
               do jtst = 1, nctst
                  xi    = xctst(jtst)*rcirc
                  yj    = yctst(jtst)*rcirc
                  atsti = actst(jtst)*rcirc**2
                  call bck
     & (ncl, jcl, sths, cths, sthv, cthv, sphi,
     & cphi, calph, xi, yj, zk, sxuj, sxdj)
                  sxyu = sxyu + sxuj*atsti
                  sxyd = sxyd + sxdj*atsti
               enddo
               sumu = sumu + sxyu*aztsti
               sumd = sumd + sxyd*aztsti
            endif
c                                                       cone
            if (hc1j .gt. 0d0) then
               sxyu   = 0.d0
               sxyd   = 0.d0
               aztsti = acztst(itst)/2.d0*hc1j
               zk     = (zctst(itst) + 1.d0)/2.d0*hc1j
               rcirc  = aell*(1.d0 - zk/hc1j)
               do jtst = 1, nctst
                  xi    = xctst(jtst)*rcirc
                  yj    = yctst(jtst)*rcirc
                  atsti = actst(jtst)*rcirc**2
                  call bck
     & (ncl, jcl, sths, cths, sthv, cthv, sphi,
     & cphi, calph, xi, yj, zk, sxuj, sxdj)
                  sxyu = sxyu + sxuj*atsti
                  sxyd = sxyd + sxdj*atsti
               enddo
               sumu = sumu + sxyu*aztsti
               sumd = sumd + sxyd*aztsti
            endif
         enddo
         bdgfu(jcl) = sumu
         bdgfd(jcl) = sumd
      endif
c
c
c    The probability to see sunlit stem
c
      btr1uj = 0.d0
      btr1dj = 0.d0
      utyu  = 0.d0
*     utyd  = 0.d0
c                       zvari - the height of the crown shade 
      tgths = sths/cths
      tgthv = sthv/cthv
      tgthx = max(tgths, eps)
      if (lellj) then
         zv = sqrt(a2 + (cell*tgths)**2)/tgthx
      else
         zv = aell/tgthx
      endif
      zvari = htrj - hcrj - zv
c
      if (zvari .gt. 0.d0) then
         if (thv .lt. ths) then
            tgthx = max(tgthv, eps)
            if (lellj) then 
               xxx = sqrt(a2 + (cell*tgthx)**2)
               zv = xxx/tgthx
            else
               zv = aell/tgthx
            endif
            zview = max(zvari , 0.d0)
         else 
            zview = zvari
         endif
c
c                        ! uty - the area of sunlit stem
         utyd = dbh(jcl)*pi/2.d0*zvari
         utyu = dbh(jcl)*pi/2.d0*zview
c                               ! the integral of pooi over [0, zvari]
         dzenel = hcrj/ntstz
         if (zvari .le. dzenel) then
            dztrunk = zvari
         else
            dztrunk = dzenel
         endif
         nz = int(zvari/dztrunk + .5d0)
         nview = int(zview/dztrunk + .5d0) + 1
         dztrunk = zvari/nz
         x1      = 0.d0
         x2      = x1
         x3      = x1
         y1      = 0.d0
         y2      = y1
         y3      = y1
         rlls1   = 0.d0
         rllv2   = 0.d0
         rllv3   = 0.d0
         chs1    = 0.d0
         chs3    = 0.d0
c
         if (nview .lt. nz) then
            do 40 k = 1, nz + 1
               z1   = (k - 1)*dztrunk
               z2   = z1
               z3   = z1
c
      call spooj
     & (ncl, x1, y1, z1, x2, y2, z2, x3, y3, z3,
     & rlls1, rllv2, rllv3, sths, cths, sthv, cthv,
     & sphi, cphi, calph, chs1, chs3, poou, pood)
c
               if (k .eq. 1 .or. k .eq. nz) pood = pood/2.d0
               btr1dj = btr1dj + pood
               if (k .eq. 1 .or. k .eq. nview) poou = poou/2.d0
               if (k .le. nview) btr1uj = btr1uj + poou
40          continue
            btr1dj = btr1dj/nz
            btr1uj = btr1uj/nview
         else
            do 41 k = 1, nz + 1
               z1   = (k - 1)*dztrunk
               z2   = z1
               z3   = z1
c     
      call spooj
     & (ncl, x1, y1, z1, x2, y2, z2, x3, y3, z3,
     & rlls1, rllv2, rllv3, sths, cths, sthv, cthv,
     & sphi, cphi, calph, chs1, chs3, poou, pood)
c           
               if (k .eq. 1 .or. k .eq. nz) then
                  pood = pood/2.d0
                  poou = poou/2.d0
               endif
               btr1dj = btr1dj + pood
               btr1uj = btr1uj + poou
41          continue
            btr1dj = btr1dj/nz
            btr1uj = btr1uj/nz
         endif
      endif
      pxx = utyu*stdns(jcl)*tgths*tgthv*(pi - phi)/pi
      btr1u(jcl) = btr1uj*pxx
      btr1d(jcl) = btr1dj*pxx
c
      return
      end
*
************************************************************************
*
