      subroutine hetk8o
     & (ncl, jwl, ths, thv, phi, stdns, uuu, eln3, thm3, 
     & ghg, bdgfu, bdgfd, btr1u, btr1d, 
     & pkhair, rnlf, rtrnk, bi0u, bi0d)
c
c     Replaced the phase function by M. Mõttus by the Henyey-Greenstein
c     phase function, 01.2013
c
c     Phase function of conifer shoots by M. Mõttus (Agricult. & Forest
c     Meteorol., 154-155, 67-74 (2012)), 01.2013
c
c     Single scattering radiance of tree crowns, up and down
c     A. Kuusk  27.11.2000
c
c  Input:
c      & (ncl, jwl, phi, stdns, uuu,
c      & bdgfu, bdgfd, btr1uk, btr1dk, pkhair, rnlf, rtrnk, rrs, ttt,
c  Output:
c      bi0u, bi0d
c
      include 'par.h'
      include 'spectra.h'
c      
      dimension stdns(nclmax), uuu(nclmax)
      dimension bdgfu(nclmax), btr1u(nclmax)
      dimension bdgfd(nclmax), btr1d(nclmax)
      dimension rnlf(nclmax), rtrnk(nclmax)
      dimension eln3(nclmax), thm3(nclmax), ghg(nclmax)
c
*     data pi/3.14159265358979d0/
      data eps/.01d0/, eps2/.0001d0/
c
      sthv  = sin(thv)
      cthv  = cos(thv)
      cphi    = cos(phi)
      sphi    = sin(phi)
c 
      cths  = cos(ths)
      sths  = sin(ths)
*     tgths   = sths/cths
      calph   = sthv*sths*cphi + cthv*cths
      alpha   = acos(calph)
      aalpha  = abs(alpha)
      if (aalpha .lt. eps) alpha = 0.d0
      if (alpha .lt. 0.d0) alpha = alpha + pi
      salph   = sin(alpha)
      calp2u  = cos(alpha*.5d0)
      calp2d  = sqrt((1.d0 - calph)/2.d0)
c
      bbbu    = 0.d0
      bbbd    = 0.d0
c                       ! Summing over tree classes
      do 180 jcl = 1, ncl
        ulj    = uuu(jcl)
        rdlf   = rrs(jcl, jwl)
        tleaf  = ttt(jcl, jwl)
        rnj    = rnlf(jcl)
        thmj   = thm3(jcl)
        eej    = 1.d0 - exp(-eln3(jcl))
c
        if (ghg(jcl) .le. .0d0) then
          szg    = 1.d0
          ellmyj = abs(.059d0*eln3(jcl) *(thmj - 1.02d0) + .02d0)
          ellsij = abs(.0107d0 - .0216d0*eln3(jcl)*(thmj - .265d0))
c
c                 ! Phase function of scattering gamma
c                 ! the upper hemisphere (diffuse + specular)
          call gamma
     & (thv, ths, phi, thmj, eej, szg, rdlf, tleaf, rnj,
     & pkhair, ellmyj, ellsij, gg1, gg2, gamm)
c
        else
c  The Henyey-Greenstein phase function
          ghgj = ghg(jcl)
          omg   = rdlf + tleaf
          gammd = (1.d0 - ghgj*ghgj)/sqrt((1.d0 + ghgj*ghgj -
     &            2.d0*ghgj*calph)**3)/(4.d0*pi)*omg
c                           ! Phase function of specular reflection
          call gmfres(calp2u, rnj, pkhair, gmf)
          if (eej .le. eps) then
             gl  = 1.d0
          else
             y4  = abs(cthv + cths)*.5d0/calp2u
             thp = acos(y4)
             call gleaf(thmj, eej, thp, gl)
          endif
          gammf = gmf*gl*.125d0
          gamm  = gammd + gammf
        endif
*
*       print *, 'thv, alpha, gamme, gammil, gamm, gl, gammf', 
*    &    thv/dr, alpha/dr, gamme, gammil, gamm, gl, gammf
c
        psv = bdgfu(jcl)*ulj*stdns(jcl)/(cths*cthv)
        bc1u = psv*gamm
*       bc1u    = bdgfu(jcl)*gamm*ulj*stdns(jcl)/
*    &                (cths*cthv)
c
*           psv = bdgfu(jcl)*ulj*stdns(jcl)
*           gsv = gamm/(cths*cthv)
*            write (0, '(a,3x,6f10.6)')
*    &  "hetk8o: ", thv/dr, ths/dr, psv, gsv
c
c                        ! Phase function gamma, vertical orientation
c                        ! tty = 0, rfr = 0, the upper hemisphere
        gammout = rtrnk(jcl)*(sphi - (phi - pi)*cphi)/(2.d0*pi)
c
        btr1uj   = btr1u(jcl)*gammout
c
        bbbu    = bbbu + bc1u + btr1uj
c
c                                  ! the lower hemisphere
        gammr = (salph + (pi - alpha)*calph)/(3.d0*pi)
        gammt = (salph - alpha*calph)/(3.d0*pi)
        gammd = rdlf*gammt + tleaf*gammr
c
        if (calp2d .lt. eps2) then
          rfr = 0.d0
        else
          call gmfres(calp2d, rnj, pkhair, rfr)
        endif
c
        gammout = gammd + rfr*.125d0
c
        bc1d    = bdgfd(jcl)*gammout*ulj*stdns(jcl)/
     &            (cths*cthv)
c                    ! Phase function gamma, vertical orientation
c                    ! tty = 0, rfr = 0
c                    ! the lower hemisphere
        gammout = rtrnk(jcl)*(sphi - phi*cphi)/(2.d0*pi)
c
*       btr1dj  = btr1d(jcl)*gammout*stdns(jcl)*
*    &            tgths*sthv/cthv
        btr1dj  = btr1d(jcl)*gammout
        bbbd    = bbbd + bc1d + btr1dj

180   continue
c 
      bi0u   = bbbu
      bi0d   = bbbd
c
c
      return
      end
*
***********************************************************************
*
