      subroutine layer
     & (thets, thetv, ggs, ggv, ggj, utot, rleff, tleff,
     & rdd, tdd, rdo, tdo, rsd, tsd, rso)
c
c  Diffuse reflection and transmission of a layer from the SAIL model
c  for elliptical leaf orientation. A. Kuusk  13.01.2000.
c  Approximations for small absorption added 22.07.2009.
c
c  thets - the Sun zenith, thetv - view angle
c  ggs, ggv - G-function at thets and thetv
c  ggj  - the J-integral in the SAIL model
c  rleff, tleff - leaf reflection and transmission
c  rdd, tdd - diffuse reflectance and transmittance of a layer
c             in 2-stream approximation
c  rdo - diffuse reflectance of the upper surface of the layer,
c  rsd, tsd - diffuse reflectance and transmittance of the layer
c             for direct incoming radiation
c  rso - diffuse reflectance of the layer in view direction
c        for direct incoming radiation
c        the angular dependence from the SAIL model
c
*     implicit double precision (a-h, o-z)
      include 'par.h'
      data eps/.1d-5/
c
*     eint(xy) = (1.d0 - exp(-xy))/xy
c
      rtp   = (rleff + tleff)/2.d0
      rtm   = (rleff - tleff)/2.d0
      bf    = rtm*ggj
c
      vks   = ggs/cos(thets)
      vkv   = ggv/cos(thetv)
      vsig  = rtp + bf
      vatt  = 1.d0 - rtp + bf
      vssf  = vks*rtp - bf
      vssb  = vks*rtp + bf
      vmm2  = vatt**2 - vsig**2
      vmm   = sqrt(vmm2)
      vvv   = vkv*rtp + bf
      vuu   = vkv*rtp - bf
      vh1   = (vatt + vmm)/vsig
      vh2   = 1.d0/vh1
      vcc   = (vssf*vsig - vssb*(vks - vatt))/(vmm2 - vks**2)
      vdd   = (vssb*vsig + vssf*(vks + vatt))/(vmm2 - vks**2)
c
      exku1 = exp(-vks*utot)
      if (vmm .lt. eps) then
c                                                  ! small absorption
        exku2 = exp(-vkv*utot)
        xxx   = (2.d0 + utot*(1.d0 + vmm2))
        yy1   = eint((vkv - vmm)*utot)
        yy2   = eint((vkv + vmm)*utot)
        yy3   = eint(vkv*utot)
        xx3   = (1.d0 - (1.d0 + vkv*utot)*exku2)/(vkv*vkv - vmm2)
        rdd   = utot*(1.d0 - vmm2)/xxx
        tdd   = 2.d0/xxx
        tsd   = vdd*(exku1 - tdd) - 
     &          (1d0 - vmm2)*utot*vcc*exku1/xxx
        rsd   = vcc - (2.d0*vcc*exku1 + vdd*utot*(1.d0 - vmm2))/xxx
        tdo   = (((vuu*(1.d0 + vmm2) + vvv*(1.d0 - vmm2))*xx3) +
     &          utot*vuu*(yy1 + yy2))/xxx
        rso   = (((1.d0 + vkv*utot)*exku2 - 1.d0)*(vvv+vuu)*
     &       (vcc*exku2 - vdd) -
     &       utot*vkv*vkv*(2.d0*vuu*vcc*exku2 + (vuu + vvv)*utot*vdd +
     &       2.d0*vvv*vdd)*yy3)/(2.d0 + utot)/vkv/vkv +
     &       utot*(vvv*vdd + vuu*vcc)*eint((vkv + vks)*utot)
        rdo   = ((vvv + vuu)*((1.d0 + vkv*utot)*exku2 - 1.d0) +
     &          utot*vkv*vkv*(vvv*(2.d0 + utot) + vuu*utot)*yy3)/
     &          (2.d0 + utot)/vkv/vkv
      else
        exmu1 = exp(vmm*utot)
        exmu2 = 1.d0/exmu1
        delt  = vh1*exmu1 - vh2*exmu2
        rdd   = (exmu1 - exmu2)/delt
        tdd   = (vh1 - vh2)/delt
        delta = vh2*vcc*exku1 - vdd*exmu1
        deltb = vdd*exmu2 - vh1*vcc*exku1
        tsd   = (vcc*(exku1*(exmu2 - exmu1)) +
     &          vdd*(vh2 - vh1))/delt + vdd*exku1
        rsd   = (delta + deltb)/delt + vcc
        tdo   = utot*((vuu*vh1 + vvv)*eint((vkv - vmm)*utot) -
     &          (vuu*vh2 + vvv)*eint((vkv + vmm)*utot))/delt
        rso   = utot*((vvv*vdd + vuu*vcc)*eint((vkv + vks)*utot) +
     &          ((vvv*vh1 + vuu)*delta*eint((vkv + vmm)*utot) +
     &          (vvv*vh2 + vuu)*deltb*eint((vkv - vmm)*utot))/delt)
        rdo   = utot*(exmu1*(vvv*vh1 + vuu)*eint((vkv + vmm)*utot) -
     &          exmu2*(vvv*vh2 + vuu)*eint((vkv - vmm)*utot))/delt
      endif
c
      return
      end
*
**********************************************************************
*
