      subroutine spooj
     & (ncl, x1, y1, z1, x2, y2, z2, x3, y3, z3,
     & rlls1, rllv2, rllv3, sths, cths, sthv, cthv,
     & sphi, cphi, calph, chs1, chs3, poou, pood)
c
c   Elliptical LAD of tree foliage  12.2012
c   Bidirectional gap probability outside tree crowns,  A. Kuusk 22.05.1998
c
c  Input:
c    lelli, ncl, uuu, shl, stdns, htr, hc1, hc2, rcr, dbh, gg3s, gg3v, 
c    & glmp, x1, y1, z1, x2, y2, z2, x3, y3, z3, rlls1, rllv2, rllv3,
c    & sths, cths, sthv, cthv, sphi, cphi, calph, chs1, chs3
c  Output:
c    poou, pood
c
c   Crown projections are replaced by circles of same area.
c   (xi, yi, zi) - intersection points of sun and view rays, and crown
c   perimeter: i=1 - view ray up, i=2 - sun, i=3 - view ray down,
c
c   poou - upper hemisphere, pood - lower hemisphere, 22.11.2000
c   An error in scomm (small sl8 values) fixed on 25.04.2002
c   Elliptical LAD in tree crowns, 03.12.2012
c
      include 'par.h'
      include 'stands.h'
c
      logical lthsv
c
      data eps1/.1d-3/, eps2/.2d-5/, eps3/.1d-6/
c
      rintegr(xxx) = (1.d0 - exp(-xxx))/xxx
c
      lthsv = (abs(sthv - sths) .lt. eps2) .and. 
     & (abs(cphi - 1.d0) .lt. eps2)
      sumu  = 0.d0
      sumd  = 0.d0
      azs   = 0.d0
      tgths = sths/cths
      tgthv = sthv/cthv
      do 200 jcl = 1, ncl
         rlls2  = 0.d0
         rllv2u = 0.d0
         rllv2d = 0.d0
         x8     = 0.d0
         y8     = 0.d0
         lellj  = lelli(jcl)
         uuuj   = uuu(jcl)
         ulgs   = uuuj*gg3s(jcl)
         ulgv   = uuuj*gg3v(jcl)
         rcrj   = rcr(jcl)
         htrj   = htr(jcl)
         dbhj   = dbh(jcl)
         hc1j   = hc1(jcl)
         hc2j   = hc2(jcl)
         shlj   = shl(jcl)
         glmp1j = 1.d0 - glmp
         if (lellj) then
            hbase = htrj - hc1j
         else
            hbase = htrj - (hc1j + hc2j)
         endif
c                             crown projection in view direction (up)
         if (z1 .lt. htrj) then
            call crproju
     &        (lellj, tgthv, z1, htrj, hc1j, hc2j, rcrj, szu1, vzuj)
c
            if (szu1 .gt. 0.d0) then
               rllv2u = vzuj/szu1/cthv
               azvu  = exp(-ulgv*rllv2u)
               sl1   = ((htrj + max(z1, hbase))*.5d0 - z1)
     &                *tgthv
            else
               azvu  = 0.d0
               sl1   = 0.d0
            endif
         else
            azvu  = 0.d0
            sl1   = 0.d0
            szu1  = 0.d0
         endif
c                               stem projection in view direction (up)
         slty1 = 0.d0
         slty2 = 0.d0
         if (z1 .lt. hbase) then
            slty1 = (hbase - z1)*tgthv
            call stem(z1, hbase, dbhj, htrj, styx)
            sty1  = styx*tgthv
         else
            sty1  = 0.d0
         endif
c
c                              pooj up using binome equation, 28.05.1998
c                              the first coefficient
         b11j = bij(azvu, glmp)
c
      if (lthsv) then 
c                              hot-spot
          b2jz  = b11j
          b12j  = b11j
          szu2  = szu1
          scomm = szu1
          sty2  = sty1
          scty  = sty1
      else
c                                 crown projection in Sun direction
         if (z2 .lt. htrj) then
            call crproju
     &        (lellj, tgths, z2, htrj, hc1j, hc2j, rcrj, szu2, vzuj)
c
            if (szu2 .gt. 0.d0) then
               rlls2 = vzuj/szu2/cths
               azs   = exp(-ulgs*rlls2)
               sl2   = ((htrj + max(z2, hbase))*.5d0 - z2)*tgths
            else
               azs   = 0.d0
               sl2   = 0.d0
            endif
         else
            azs  = 0.d0
            sl2  = 0.d0
            szu2 = 0.d0
         endif
c                                 stem projection in Sun direction
         if (z2 .lt. hbase) then
            slty2 = (hbase - z2)*tgths
            call stem(z2, hbase, dbhj, htrj, styx)
            sty2  = styx*tgths
         else
            sty2  = 0.d0
         endif
c                             the distance between projection centres
         x8  = x2 + sl2
         y8  = y2
         x7  = x1 + sl1*cphi
         y7  = y1 + sl1*sphi
         sl8 = sqrt((x7 - x8)**2 + (y7 - y8)**2)
c
c                                     common area of stem projections
         if (sty1 .gt. 0.d0 .and. sty2 .gt. 0.d0) then
            if (cphi .lt. -eps3) then
               scty = 0.d0
            else if (abs(y1 - y2) .lt. eps1) then
               x5  = x2 + slty2
               x6  = x1 + slty1*cphi
               if (abs(x1 - x2) .lt. eps1) then
                  tstphi = dbhj/min(slty1, slty2)
                  if (sphi .gt. tstphi) then
                     scty = dbhj**2*.5d0/sphi
                  else if ((min(x5, x6) - max(x1, x2)) .gt. 0.d0) then
                     scty = (min(x5, x6) - max(x1, x2))*dbhj
                  else
                     scty = 0.d0
                  endif
               else
                  if (sphi .gt. eps3) then
                     scty = 0.d0
                  else if ((min(x5, x6) - max(x1, x2)) .gt. 0.d0) then
                     scty = (min(x5, x6) - max(x1, x2))*dbhj
                  else
                     scty = 0.d0
                  endif
               endif
            else
               scty = 0.d0
            endif
         else
            scty = 0.d0
         endif
c
c                                     common area of crown projections
         ss1 = max(szu1, szu2)
         ss2 = min(szu1, szu2)
         rc1 = sqrt(ss1/pi)
         rc2 = sqrt(ss2/pi)
         if (sl8 .ge. (rc1 + rc2)) then
            scomm = 0.d0
         else if ((sl8 .le. (rc1 - rc2)) .or. sl8 .le. eps2) then
            scomm = ss2
         else
            ppp   = (rc1 + rc2 + sl8)*.5d0
            angl4 = acos((rc1**2 + sl8**2 - rc2**2)/(2.d0*rc1*sl8))
            angl8 = acos((rc1**2 + rc2**2 - sl8**2)/(2.d0*rc1*rc2))
            angl5 = (pi - angl4 - angl8)
            ss4   = angl4*rc1**2
            ss5   = angl5*rc2**2
            ss6   = sqrt(ppp*(ppp - rc1)*(ppp - rc2)*(ppp - sl8))
            scomm = ss4 + ss5 - 2.d0*ss6
         endif
c
c                                        ! external hot-spot correction
         rlls = rlls1 + rlls2
         rllv = rllv2 + rllv2u
         rl12 = (rllv - rlls)**2 + (1.d0 - calph)*2.d0*rlls*rllv
         if (rl12 .lt. 0.d0) then
            crr2 = 0.d0
         else
            crr2 = sqrt(rl12)/shlj
         endif
         if (crr2 .lt. eps1) then
            xtmp = 1.d0 - crr2*.5d0
         else
            xtmp = rintegr(crr2)
         endif
         chs2 = exp((sqrt(rllv*rlls)*xtmp - chs1)*sqrt(ulgs*ulgv))
c
         azvs  = azvu*azs*chs2
c                                           *** chs2 kontroll
         ztmp = 1.d0 - (1.d0 - azvs)*glmp
         if (ztmp .le. 0.d0) then
           azvs = (glmp1j - 1.d0 + eps1)/glmp1j
         endif
         b12j = bij(azs, glmp)
         b2jz = bij(azvs, glmp)
c
      endif
c
      styx = min(sty1, sty2)
      styx = min(styx, scty)
      styx = sty1 + sty2 - styx
c
      sumu = sumu + stdns(jcl)*(b11j*(szu1 - scomm) +
     &       b12j*(szu2 - scomm) + b2jz*scomm + styx)
*     write (*, '(a/ 8f12.6)')
*    & '#sumu:', sumu, b11j, szu1, scomm, b12j, szu2, b2jz, styx
c
c
c                             crown projection in view direction (down)
         if (z3 .gt. hbase) then
            call crprojd
     &        (lellj, tgthv, z3, htrj, hc1j, hc2j, rcrj, szd3, vzdj)
c
            if (szd3 .gt. 0.d0) then
               rllv2d = vzdj/szd3/cthv
               azvd  = exp(-ulgv*rllv2d)
               sl3  = ((hbase + z3)*.5d0 - hbase)*tgthv
            else
               azvd  = 0.d0
               sl3   = 0.d0
            endif
         else
            azvd  = 0.d0
            sl3   = 0.d0
            szd3  = 0.d0
         endif
c                               stem projection in view direction (down)
         slty3 = min(z3, hbase)
         zx1 = 0.d0
         zx2 = slty3
         call stem(zx1, zx2, dbhj, htrj, styx)
         sty3  = styx*tgthv
c                               pooj down using binome equation, 28.05.1998
c                               the first coefficient
         b11j = bij(azvd, glmp)
c
         x7  = x3 - sl3*cphi
         y7  = y3 - sl3*sphi
         sl8 = sqrt((x7 - x8)**2 + (y7 - y8)**2)
c
c                                     common area of stem projections
         if (sty3 .gt. 0.d0 .and. sty2 .gt. 0.d0) then
            if (-cphi .lt. -eps3) then
               scty = 0.d0
            else if (abs(y3 - y2) .lt. eps1) then
               x5  = x2 + slty2
               x6  = x3 - slty3*cphi
               if (abs(x3 - x2) .lt. eps1) then
                  tstphi = dbhj/min(slty3, slty2)
                  if (sphi .gt. tstphi) then
                     scty = dbhj**2*.5d0/sphi
                  else if ((min(x5, x6) - max(x3, x2)) .gt. 0.d0) then
                     scty = (min(x5, x6) - max(x3, x2))*dbhj
                  else
                     scty = 0.d0
                  endif
               else
                  if (sphi .gt. eps3) then
                     scty = 0.d0
                  else if ((min(x5, x6) - max(x3, x2)) .gt. 0.d0) then
                     scty = (min(x5, x6) - max(x3, x2))*dbhj
                  else
                     scty = 0.d0
                  endif
               endif
            else
               scty = 0.d0
            endif
         else
            scty = 0.d0
         endif
c
c                                     common area of crown projections
         ss1 = max(szd3, szu2)
         ss2 = min(szd3, szu2)
         rc1 = sqrt(ss1/pi)
         rc2 = sqrt(ss2/pi)
         if (sl8 .ge. (rc1 + rc2)) then
            scomm = 0.d0
         else if ((sl8 .le. (rc1 - rc2)) .or. sl8 .le. eps2) then
            scomm = ss2
         else
            ppp   = (rc1 + rc2 + sl8)*.5d0
            s34   = ppp*(ppp - rc1)*(ppp - rc2)*(ppp - sl8)
            sl4   = 2.d0/sl8*sqrt(s34)
            angl1 = 2.d0*asin(sl4/rc1)
            angl2 = 2.d0*asin(sl4/rc2)
            ss4   = rc1**2*.5d0*(angl1 - sin(angl1))
            ss5   = rc2**2*.5d0*(angl2 - sin(angl2))
            scomm = ss4 + ss5
         endif
c
c                                        ! external hot-spot correction
         rlls = rlls1 + rlls2
         rllv = rllv3 + rllv2d
         rl12 = (rllv - rlls)**2 + (1.d0 + calph)*2.d0*rlls*rllv
         if (rl12 .lt. 0.d0) then
            crr2 = 0.d0
         else
            crr2 = sqrt(rl12)/shlj
         endif
         if (crr2 .lt. eps1) then
            xtmp = 1.d0 - crr2*.5d0
         else
            xtmp = rintegr(crr2)
         endif
         chs2 = exp((sqrt(rllv*rlls)*xtmp - chs3)*sqrt(ulgs*ulgv))
c
         azvs  = azvd*azs*chs2
         b12j = bij(azs, glmp)
         b2jz = bij(azvs, glmp)
c
         styx = min(sty3, sty2)
         styx = min(styx, scty)
         styx = sty3 + sty2 - styx
         sumd = sumd + stdns(jcl)*(b11j*(szd3 - scomm) +
     &         b12j*(szu2 - scomm) + b2jz*scomm + styx)
c
200   continue
c
      poou = exp(-sumu)
c
*         if (abs(sumd) .gt. 3000.d0) then
*           print *, 'sumd = ', sumd
*         endif
      pood = exp(-sumd)
c
      return
      end
*
************************************************************************
*
